@@ -9,6 +9,7 @@ from .by_plugin import AuthByPlugin, AuthType
 from .default import AuthByDefault
 from .idtoken import AuthByIdToken
 from .keypair import AuthByKeyPair
+from .no_auth import AuthNoAuth
 from .oauth import AuthByOAuth
 from .okta import AuthByOkta
 from .pat import AuthByPAT
@@ -25,6 +26,7 @@ FIRST_PARTY_AUTHENTICATORS = frozenset(
         AuthByWebBrowser,
         AuthByIdToken,
         AuthByPAT,
+        AuthNoAuth,
     )
 )
 
@@ -37,6 +39,7 @@ __all__ = [
     "AuthByOkta",
     "AuthByUsrPwdMfa",
     "AuthByWebBrowser",
+    "AuthNoAuth",
     "Auth",
     "AuthType",
     "FIRST_PARTY_AUTHENTICATORS",
